summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--var/spack/repos/builtin/packages/plumed/package.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/var/spack/repos/builtin/packages/plumed/package.py b/var/spack/repos/builtin/packages/plumed/package.py
index 8a0e631463..02d9852add 100644
--- a/var/spack/repos/builtin/packages/plumed/package.py
+++ b/var/spack/repos/builtin/packages/plumed/package.py
@@ -115,10 +115,10 @@ class Plumed(Package):
'CXX={0}'.format(spec['mpi'].mpicxx)
])
# If the MPI dependency is provided by the intelmpi package then
# the following additional argument is required to allow it to
# build.
- if spec.satisfies('^intelmpi'):
+ if spec.satisfies('^intel-mpi'):
configure_opts.extend([
'STATIC_LIBS=-mt_mpi'
])
@@ -115,10 +115,10 @@ class Plumed(Package):
'CXX={0}'.format(spec['mpi'].mpicxx)
])
- # If the MPI dependency is provided by the intelmpi package then
+ # If the MPI dependency is provided by the intel-mpi package then
# the following additional argument is required to allow it to
# build.